@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.010001;
 
-our $VERSION = '1.112_03';
+our $VERSION = '1.113_01';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -108,61 +108,38 @@ sub __validate_options {
         prompt          => '',
         undef           => '',
     };
-    my @warn = ();
+    my $sub =  ( caller( 1 ) )[3];
+    $sub =~ s/^.+::([^:]+)\z/$1/;
     for my $key ( keys %$opt ) {
         if ( ! exists $valid->{$key} ) {
-            push @warn, "'$key' is not a valid option name";
-            next;
+            croak "$sub: '$key' is not a valid option name";
         }
         next if ! defined $opt->{$key};
-        if ( $valid->{$key} eq '' && ! ref $opt->{$key} ) {
-            $self->{$key} = $opt->{$key};
-        }
-        elsif ( $key eq 'lf' ) {
-            my $err;
-            if ( ref $opt->{$key} eq 'ARRAY' && @{$opt->{$key}} <= 2 ) {
-                no warnings 'uninitialized';
-                /^[0-9]+\z/ || ++$err && last for @{$opt->{$key}};
+        if ( $key eq 'lf' ) {
+            if ( ! ( ref $opt->{$key} eq 'ARRAY' && @{$opt->{$key}} <= 2 ) ) {
+                croak "$sub: option '$key' : the passed value has to be an ARRAY reference.";
             }
-            else {
-                ++$err;
-            }
-            if ( $err ) {
-                push @warn, "option '$key' : the passed value is not a valid value. Falling back to the default value";
-            }
-            else {
-                $self->{$key} = $opt->{$key};
+            no warnings 'uninitialized';
+            for ( @{$opt->{$key}} ) {
+                /^[0-9]+\z/ or croak "$sub: option '$key' : $_ is an invalid array element";
             }
         }
         elsif ( $key eq 'no_spacebar' ) {
-            my $err;
-            if ( ref $opt->{$key} eq 'ARRAY' ) {
-                no warnings 'uninitialized';
-                /^[0-9]+\z/ || ++$err && last for @{$opt->{$key}};
+            if ( ref $opt->{$key} ne 'ARRAY' ) {
+                croak "$sub: option '$key' : the passed value has to be an ARRAY reference.";
             }
-            else {
-                ++$err;
-            }
-            if ( $err ) {
-                push @warn, "option '$key' : the passed value is not a valid value. Falling back to the default value";
-            }
-            else {
-                $self->{$key} = $opt->{$key};
+            no warnings 'uninitialized';
+            for ( @{$opt->{$key}} ) {
+                /^[0-9]+\z/ or croak "$sub: option '$key' : $_ is an invalid array element";
             }
         }
-        elsif ( $opt->{$key} =~ m/^$valid->{$key}\z/x ) {
-            $self->{$key} = $opt->{$key};
+        elsif ( $valid->{$key} eq '' && ref $opt->{$key} ne '' ) {
+            croak "$sub: option '$key' : references are not valid values.";
         }
-        else {
-            push @warn, "option '$key' : '$opt->{$key}' is not a valid value. Falling back to the default value";
+        elsif ( length $valid->{$key} && $opt->{$key} !~ m/^$valid->{$key}\z/x ) {
+            croak "$sub: option '$key' : '$opt->{$key}' is not a valid value.";
         }
-    }
-    if ( @warn ) {
-        for my $w ( @warn ) {
-            carp "choose: " . $w;
-        }
-        print "Press a key to continue";
-        my $dummy = <STDIN>;
+        $self->{$key} = $opt->{$key};
     }
 }
 
@@ -1138,7 +1115,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.112_03
+Version 1.113_01
 
 =cut
 
@@ -1671,6 +1648,8 @@ default: "<undef>"
 
 =head2 carp
 
+Passing invalid options will become fatal with the next release!
+
 =over
 
 =item * If the array referred by the first argument is empty C<choose> warns and returns C<undef> respective an empty
@@ -1715,10 +1694,6 @@ Additionally, if the OS is MSWin32
 
 L<Win32::Console>
 
-=item
-
-L<Win32::Console::ANSI>
-
 =back
 
 are required. Else
@@ -1741,32 +1716,6 @@ C<choose> expects decoded strings as array elements.
 
 For a correct output it is required an appropriate encoding layer for STDOUT matching the terminal's character set.
 
-=head3 MSWin32 operating systems
-
-C<Term::Choose> uses L<Win32::Console::ANSI> if the operating system is MSWin32.
-
-C<Win32::Console::ANSI> enables the Windows own codepage conversion globally. C<Term::Choose> disables this codepage
-conversion by printing the C<"\e(U"> escape sequence - see C<"\e(U"> in
-L<Win32::Console::ANSI/Escape_sequences_for_Select_Character_Set>.
-
-In a future release of C<Term::Choose> the C<"\e(U"> escape sequence will probably be removed.
-
-You can already gain the C<Win32::Console::ANSI> default (codepage conversion enabled) by setting the environment variable
-TC_KEEP_WINDOWS_MAPPING to a true value (TC_KEEP_WINDOWS_MAPPING will become meaningless if C<"\e(U"> is removed from
-C<Term::Choose>). If you want the automatic conversion you should also ad
-
-    use Win32::Console::ANSI;
-    print "\e(K";
-
-to your code in the case that C<Win32::Console::ANSI> is removed from C<Term::Choose>.
-
-If you want to keep the automatic codepage conversion disabled add
-
-    use Win32::Console::ANSI;
-    print "\e(U";
-
-to your code.
-
 =head2 Monospaced font
 
 It is required a terminal that uses a monospaced font which supports the printed characters.
@@ -1803,7 +1752,7 @@ If the option "clear_screen" is enabled:
 
     "\e[1;1H"   Go to Top Left (Cursor Position)
 
-If the OS is MSWin32 the L<Win32::Console::ANSI> module is used to understand these escape sequences.
+If the OS is MSWin32 L<Win32::Console> is used, to emulate these escape sequences.
 
 If a I<mouse> mode is enabled
 
